function yesno = issymbolic(S)

% ISSYMBOLIC -- checks whether a matrix contains symbolic variables
%
%        yesno = issymbolic(S)
%
% This is NOT the converse of ISNUMERIC. The purpose of this routine is to 
% distinguish a matrix S whose entries are symbolic constants (which have a
% numerical value) from a matrix which contains symbolic variables.

% Copyright (c) 2004 by Fritz Keinert (keinert@iastate.edu),
% Dept. of Mathematics, Iowa State University, Ames, IA 50011.
% This software may be freely used and distributed for non-commercial
% purposes, provided this copyright statement is preserved, and
% appropriate credit for its use is given.
%
% Last update: Feb 20, 2004

try 
% Matlab cannot handle symbolic matrices of more than two
% dimensions correctly. We need to string S out first.
    S = double(simplify(S(:)));
    yesno = 0;
catch
% if S contains symbolic variables without numerical values,
% the conversion to "double" will fail. Then we end up here.
    yesno = 1;
end
